# PowerShell script to stop JBoss EAP 7.4

# Load configuration from JSON file
$config = Get-Content -Raw -Path "$PSScriptRoot\config.json" | ConvertFrom-Json

# Configuration variables from JSON
$JBOSS_HOME = $config.jbossHome

Write-Host "Stopping JBoss EAP 7.4..." -ForegroundColor Yellow

# Find and stop JBoss process
$jbossProcess = Get-CimInstance Win32_Process -Filter "Name = 'java.exe'" | 
                Where-Object { $_.CommandLine -like "*jboss.home.dir=$JBOSS_HOME*" }

if ($jbossProcess) {
    Write-Host "Found JBoss process (PID: $($jbossProcess.ProcessId))" -ForegroundColor Yellow
    Stop-Process -Id $jbossProcess.ProcessId -Force
    Write-Host "JBoss process stopped" -ForegroundColor Green
} else {
    Write-Host "No JBoss process found running" -ForegroundColor Yellow
}

# Wait a moment to ensure process is fully stopped
Start-Sleep -Seconds 2
